@@ -7,40 +7,42 @@
 ## http://search.cpan.org/dist/Devel-NYTProf/
 ##
 ###########################################################
-## $Id: NYTProf.pm 322 2008-07-15 04:33:35Z tim.bunce $
+## $Id: NYTProf.pm 405 2008-08-15 13:10:58Z tim.bunce $
 ###########################################################
 package Devel::NYTProf;
 
-package	# hide the package from the PAUSE indexer
-	DB;
+our $VERSION = '2.03';
 
-	# Enable specific perl debugger flags.
-	# Set the flags that influence compilation ASAP so we get full details
-	# (sub line ranges etc) of modules loaded as a side effect of loading
-	# Devel::NYTProf::Core (ie XSLoader, strict, Exporter etc.)
-	# See "perldoc perlvar" for details of the $^P flags
-	$^P = 0x010 # record line range of sub definition
-	    | 0x100 # informative "file" names for evals
-	    | 0x200;# informative names for anonymous subroutines
+package    # hide the package from the PAUSE indexer
+    DB;
 
-	# XXX hack, need better option handling
-	my $use_db_sub = ($ENV{NYTPROF} && $ENV{NYTPROF} =~ m/\buse_db_sub=1\b/);
+# Enable specific perl debugger flags.
+# Set the flags that influence compilation ASAP so we get full details
+# (sub line ranges etc) of modules loaded as a side effect of loading
+# Devel::NYTProf::Core (ie XSLoader, strict, Exporter etc.)
+# See "perldoc perlvar" for details of the $^P flags
+$^P = 0x010     # record line range of sub definition
+    | 0x100     # informative "file" names for evals
+    | 0x200;    # informative names for anonymous subroutines
 
-	$^P |=0x002 # line-by-line profiling (if $DB::single true)
-	    | 0x020 # start (after BEGINs) with single-step on
-			if $use_db_sub;
+# XXX hack, need better option handling
+my $use_db_sub = ($ENV{NYTPROF} && $ENV{NYTPROF} =~ m/\buse_db_sub=1\b/);
 
-	require Devel::NYTProf::Core; # loads XS
+$^P |= 0x002    # line-by-line profiling (if $DB::single true)
+    | 0x020     # start (after BEGINs) with single-step on
+    if $use_db_sub;
 
-	if ($use_db_sub) {	# install DB::DB sub
-		*DB = ($] < 5.008008)
-			? sub { goto &DB_profiler } # workaround bug in old perl versions (slow)
-			: \&DB_profiler;
-	}
+require Devel::NYTProf::Core;    # loads XS
 
-	init_profiler(); # provides true return value for module
+if ($use_db_sub) {               # install DB::DB sub
+    *DB = ($] < 5.008008)
+        ? sub { goto &DB_profiler }    # workaround bug in old perl versions (slow)
+        : \&DB_profiler;
+}
 
-	# put nothing here!
+init_profiler();                       # provides true return value for module
+
+# put nothing here!
 
 __END__
 
@@ -67,12 +69,14 @@ Devel::NYTProf is a powerful feature-rich perl source code profiler.
  * Performs per-subroutine statement profiling for overview
  * Performs per-block statement profiling (the first profiler to do so)
  * Accounts correctly for time spent after calls return
- * Performs inclusive timing of subroutines, per calling location
- * Can profile compile-time activity or just run-time
+ * Performs inclusive and exclusive timing of subroutines
+ * Subroutine times are per calling location (a powerful feature)
+ * Can profile compile-time activity, just run-time, or just END time
  * Uses novel techniques for efficient profiling
- * Very fast - the fastest statement-profiler for perl
+ * Sub-microsecond (100ns) resolution on systems with clock_gettime()
+ * Very fast - the fastest statement and subroutine profilers for perl
  * Handles applications that fork, with no performance cost
- * Immune from noise caused by profiling overheads and i/o
+ * Immune from noise caused by profiling overheads and I/O
  * Program being profiled can stop/start the profiler
  * Generates richly annotated and cross-linked html reports
  * Trivial to use with mod_perl - add one line to httpd.conf
@@ -134,6 +138,10 @@ Subroutine entry is detected by intercepting the entersub opcode. Subroutine
 exit is detected via perl's internal save stack. The result is both extremely
 fast and very robust.
 
+Note that subroutines that recurse directly or indirectly, such as Error::try,
+will show higher subroutine inclusive times because the time spent recuring
+will be double-counted. That may change in future.
+
 =head2 Application Profiling
 
 NYTProf records extra information in the data file to capture details that may
@@ -186,31 +194,42 @@ Or you can avoid the need to add the -d option at all by using the C<PERL5OPT> e
 That's also very handy when you can't alter the perl command line being used to
 run the script you want to profile.
 
-=head1 ENVIRONMENT VARIABLES
+=head1 NYTPROF ENVIRONMENT VARIABLE
 
 The behavior of Devel::NYTProf may be modified by setting the 
 environment variable C<NYTPROF>.  It is possible to use this environment
 variable to effect multiple setting by separating the values with a C<:>.  For
 example:
 
-    export NYTPROF=trace=2:begin=1:file=/tmp/nytprof.out
+    export NYTPROF=trace=2:start=init:file=/tmp/nytprof.out
 
-=over 4
+=head2 addpid=1
 
-=item trace=N
+Append the current process id to the end of the filename.
+
+This avoids concurrent, or consecutive, processes from overwriting the same file.
+
+=head2 trace=N
 
 Set trace level to N. 0 is off (the default). Higher values cause more detailed trace output.
 
-=item begin=1
+=head2 start=...
 
-Include compile-time activity in the profile. Currently that's not the default,
-but that's likely to change in future.
+Specify at which phase of program execution the profiler should be enabled:
 
-=item subs=0
+  start=begin - start immediately (the default)
+  start=init  - start at begining of INIT phase (after compilation)
+  start=end   - start at begining of END phase
+  start=no    - don't automatically start
+
+The start=no option is handy if you want to explicitly control profiling
+by calling DB::enable_profile() and DB::disable_profile() yourself.
+
+=head2 subs=0
 
 Set to 0 to disable the collection of subroutine inclusive timings.
 
-=item blocks=0
+=head2 blocks=0
 
 Set to 0 to disable the determination of block and subroutine location per statement.
 This makes the profiler about 50% faster (as of July 2008) but you loose some
@@ -218,7 +237,7 @@ valuable information. The extra cost is likely to be reduced in later versions
 anyway, as little optimization has been done on that part of the code.
 The profiler is fast enough that you shouldn't need to do this.
 
-=item leave=0
+=head2 leave=0
 
 Set to 0 to disable the extra work done to allocate times accurately when
 returning into the middle of statement. For example leaving a subroutine
@@ -230,17 +249,20 @@ the last statement executed doesn't accumulate the time spent 'outside perl'.
 NYTProf is the only line-level profiler to measure these times correctly.
 The profiler is fast enough that you shouldn't need to disable this feature.
 
-=item use_db_sub=1
+=head2 use_db_sub=1
 
 Set to 1 to enable use of the traditional DB::DB() subroutine to perform
 profiling, instead of the faster 'opcode redirection' technique that's used by
 default. It also disables some extra mechanisms that help ensure more accurate
 results for things like the last statements in subroutines.
 
-If you find a use, or need, for use_db_sub=1 then please let us know,
-otherwise this vestige of old slower ways is likely to be removed.
+The default 'opcode redirection' technique can't profile subroutines that were
+compiled before NYTProf was loaded. So using use_db_sub=1 can be useful in
+cases where you can't load the profiler early in the life of the application.
+If this proves to be useful to you then please let us know, otherwise this
+vestige of old slower ways is likely to be removed.
 
-=item usecputime=1
+=head2 usecputime=1
 
 Measure user CPU + system CPU time instead of the real elapsed 'wall clock'
 time (which is the default).
@@ -254,11 +276,17 @@ gigahertz clocks, 0.01 seconds is like a lifetime. The cpu time clock 'ticks'
 happen so rarely relative to the activity of a most applications that you'd
 have to run the code for many hours to have any hope of reasonably useful results.
 
-=item file=...
+=head2 file=...
 
 Specify the output file to write profile data to (default: './nytprof.out').
 
-=back
+=head1 SELECTIVE PROFILING
+
+You can profile only parts of an application by calling DB::enable_profile()
+and DB::disable_profile() at the appropriate moments.
+
+Using the C<start=no> option let's you leave the profiler disabled until the
+right moment, or circumstances, are reached.
 
 =head1 REPORTS
 
@@ -300,14 +328,24 @@ For example, the Readonly module croaks with an "Invalid tie" when profiled with
 perl versions before 5.8.8. That's because L<Readonly> explicitly checking for
 certain values from caller().  We're not quite sure what the cause is yet.
 
-=head2 Subroutine exclusive time is not (currently) available
+=head2 Calls made via operator overloading
 
-Time spent within a subroutine, exclusive of time spent in any subroutines it
-calls, it not currently avalable. It's planned to be added soon.
+Calls made via operator overloading are not noticed by any subroutine profiler.
+
+=head2 goto
+
+The C<goto &$sub;> isn't recognised as a subroutine call by the subroutine profiler.
 
 =head2 Windows
 
-Currently there's no support for Windows.
+Currently there's no support for Windows. Some work is being done on a port.
+If you'd be interested in helping us port to Windows then please get in touch
+with us.
+
+=head2 #line directives
+
+The reporting code currently doesn't handle #line directives, but at least it
+warns about them. Patches welcome.
 
 =head1 BUGS
 
@@ -315,22 +353,24 @@ Possibly.
 
 =head1 SEE ALSO
 
-Screenshots of L<nytprofhtml> reports can be seen at
+Screenshots of L<nytprofhtml> v2.01 reports can be seen at
 L<http://timbunce.files.wordpress.com/2008/07/nytprof-perlcritic-index.png> and
-L<http://timbunce.files.wordpress.com/2008/07/nytprof-perlcritic-all-perl-files.png>
-plus a writeup of the new features and history of NYTProf v2 at
-L<http://blog.timbunce.org/tag/performance/> (will be soon)
+L<http://timbunce.files.wordpress.com/2008/07/nytprof-perlcritic-all-perl-files.png>.
+A writeup of the new features of NYTProf v2 can be found at
+L<http://blog.timbunce.org/2008/07/15/nytprof-v2-a-major-advance-in-perl-profilers/>
+and the background story, explaining the "why", can be found at
+L<http://blog.timbunce.org/2008/07/16/nytprof-v2-the-background-story/>.
 
 Mailing list and discussion at L<http://groups.google.com/group/develnytprof-dev>
 
 Public SVN Repository and hacking instructions at L<http://code.google.com/p/perl-devel-nytprof/>
 
 L<nytprofhtml> is a script included that produces html reports.
-
 L<nytprofcsv> is another script included that produces plain text CSV reports.
 
 L<Devel::NYTProf::Reader> is the module that powers the report scripts.  You
-might want to check this out if you plan to implement a custom report.
+might want to check this out if you plan to implement a custom report (though
+it may be deprecated in a future release).
 
 =head1 AUTHOR
 
